## This is the plugin to handle the mounting of Appleshare
## network volumes. It requires the afpfs package which
## implements an appleshare mounter
##
## Ethan Gold <etgold@cs.vassar.edu> 2/24/98
##
if {[debug]} { puts "loading Appleshare plugin..." }

## register the plugin with the main chooser
register_plugin appletalk appleshare Appleshare

#### required procedures that simply return plugin information
proc appleshare.geticon {} { return "appleshare.pnm" }
proc appleshare.getpubname {} { return "Appleshare" }
proc appleshare.getprotocol {} { return "appletalk" }

#### real plugin functionality below here##

########## required functions #################

## start function - required
proc appleshare.start {} {
    global plug_globalflat
    if {[debug]} { puts "started Appleshare Plugin" }

    set entlabel [plug_list_label]
    $entlabel configure -text "Appleshare Servers:"
    update
    appleshare.widgets stop
    appleshare.widgets start
    appleshare.newzone
}

## stop funtion - required
proc appleshare.stop {} {
    if {[debug]} { puts "stopped Appleshare Plugin" }
    appleshare.clearentities
    set ID [get_glob afterID]
    if {[string compare $ID ""] != 0 } {
	after cancel $ID
    }
    appleshare.widgets stop
}

## function to call when a listitem is double-clicked
proc appleshare.doubleclick {} {
    if {[debug]} { puts "appleshare: got double-click with [get_curr_item]" }
    appleshare.mountwindow [get_curr_item] [appletalk.getcurrzone]
}

proc appleshare.newzone {} {
    set plugframe [plug_frame]
    $plugframe.status configure -text "scanning [appletalk.getcurrzone]..."
    update
    appleshare.clearentities
    appleshare.showentities [appleshare.getnames]
    $plugframe.status configure -text "ready."
}

############# End required functions ##################

## function to build window to mount volumes
proc appleshare.mountwindow {server zone} {
    
    set username ""
    set password ""
    ## make sure something's selected
    if {[string compare $server ""] == 0} {
	return
    }
    if {[debug]} { puts "appleshare: pretending to mount $server" }

    set w ".appleshare_mountwin"
    set guestflag 0

    ## we are only going to support one mount window
    ## at a time for now. this is easily changed.
    catch {destroy $w}
    
    ## build mounting window
    toplevel $w -class Dialog
    label $w.label -text \
	    " \nConnect to the file server \"$server\" as: \n" \
	    -font [get_propfont]

    checkbutton $w.guest -variable guestflag \
	    -text "Guest" -font [get_propfont]
    label $w.spacelabel1 -text "\n"
    label $w.spacelabel2 -text "\n"
    frame $w.nameframe
    frame $w.passframe
    label $w.nameframe.namelabel -text "Name:     " -font [get_fixedfont]
    label $w.passframe.passlabel -text "Password: " -font [get_fixedfont]
    entry $w.nameframe.name -textvariable username -exportselection 0
    entry $w.passframe.pass -textvariable password -exportselection 0 -show "*"
    pack $w.nameframe.namelabel -side left -anchor n
    pack $w.nameframe.name -side right -anchor n
    pack $w.passframe.passlabel -side left -anchor n
    pack $w.passframe.pass -side right -anchor n
    button $w.cancel -text "Cancel" \
	    -command "destroy $w" -default active
    button $w.ok -text "OK" \
	    -command "destroy $w; appleshare.volist \"$server\" \"$zone\" \"\$username\" \"\$password\" \$guestflag" -default disabled

    pack $w.label -side top -padx 5
    pack $w.guest -side top -anchor w -padx 15
    pack $w.spacelabel1 -side top
    pack $w.nameframe -side top -anchor w  -padx 15
    pack $w.passframe -side top -anchor w  -padx 15
    #pack $w.spacelabel2 -side top
    pack $w.cancel -side left -anchor s -padx 10 -pady 10
    pack $w.ok -side right -anchor s -padx 10 -pady 10
    update
    focus $w.nameframe.name
    if {[debug]} { puts "appleshare: finished packing mountwin" }

    bind $w.passframe.pass <Return> "$w.ok invoke"
    bind $w <Control-c> "$w.cancel invoke"
    bind $w.cancel <Return> "$w.cancel invoke"
    bind $w.ok <Return> "$w.ok invoke"
}

## procedure to list avilale volumes and call
## the procedure that does the afpfs interaction
proc appleshare.volist {server zone username password guestflag} {
    if {[debug]} { puts "appleshare: volist: called with $server, $zone, \
	    $username, $password, $guestflag" }
    
    return

    ## create volume list dialog box and set up
    ## callbacks to mount each selected item in the listbox
    set w .applesharevolist
    set volumelist 0
    destroy $w
    toplevel $w -class Dialog
    set labeltext "$server\nSelect the items you want to use:"
    label $w.label -text $labeltext -font [get_propfont]
    listbox $w.volist -height 6 -width 30 -font [get_propfont] \
	    -yscrollcommand "$w.scroll set"
    scrollbar $w.volscroll -command "$w.volist yview"
    button $w.cancel -text "Cancel" -command "destroy $w"
    button $w.ok -text "OK" -command [list \
	    set volumelist [$w.volist curselection]; \
	    set volumelist [$w.volist get $volumelist] ]
    
    pack $w.label
    pack $w.volist
    pack $w.volscroll
    pack $w.cancel $w.ok
    update

}


## procedure to build and destroy appleshare widgets
proc appleshare.widgets {command} {
    set plugframe [plug_frame]

    if {[string compare $command "start"] == 0} {
	button $plugframe.mount -text "Mount..." \
		-command {appleshare.mountwindow \
		[get_curr_item] [appletalk.getcurrzone]}
	pack $plugframe.mount
    } else {
	destroy $plugframe.mount
    }
    
}

## function to return the laserwriters in the current zone
proc appleshare.getnames {} {
    return [appletalk.namesfromlkup [appleshare.getentities]]
}

proc appleshare.getentities {} {
    set currzone [appletalk.getcurrzone]
    set entity "=:AFPServer@$currzone"
    set results [appletalk.nbplkup $entity]
    set results [appletalk.namesfromlkup $results]
    return $results
}

## function to display passed in entities in
## the plugin's entity list frame
proc appleshare.showentities {entitylist} {
    set lbox [plug_list]
    foreach entity $entitylist {
	$lbox insert end $entity
    }
}

proc appleshare.clearentities {} {
    set lbox [plug_list]
    $lbox delete 0 end
}

if {[debug]} { puts "finished loading Appleshare." }

